@@ -21,7 +21,7 @@
 #include "dictionarycombobox.h"
 
 #include <speller.h>
-#include <qdebug.h>
+#include "ui_debug.h"
 
 namespace Sonnet
 {
@@ -30,7 +30,7 @@ namespace Sonnet
 class DictionaryComboBoxPrivate
 {
 public:
-    DictionaryComboBoxPrivate(DictionaryComboBox *combo) : q(combo) {};
+    explicit DictionaryComboBoxPrivate(DictionaryComboBox *combo) : q(combo) {}
     DictionaryComboBox *q;
     void slotDictionaryChanged(int idx);
 };
@@ -65,36 +65,48 @@ QString DictionaryComboBox::currentDictionary() const
     return itemData(currentIndex()).toString();
 }
 
-void DictionaryComboBox::setCurrentByDictionaryName(const QString &name)
+bool DictionaryComboBox::assignDictionnaryName(const QString &name)
 {
     if (name.isEmpty() || name == currentText()) {
-        return;
+        return false;
     }
 
     int idx = findText(name);
     if (idx == -1) {
-        //qDebug() << "name not found" << name;
-        return;
+        qCDebug(SONNET_LOG_UI) << "name not found" << name;
+        return false;
     }
 
     setCurrentIndex(idx);
     d->slotDictionaryChanged(idx);
+    return true;
 }
 
-void DictionaryComboBox::setCurrentByDictionary(const QString &dictionary)
+void DictionaryComboBox::setCurrentByDictionaryName(const QString &name)
+{
+    assignDictionnaryName(name);
+}
+
+bool DictionaryComboBox::assignByDictionnary(const QString &dictionary)
 {
     if (dictionary.isEmpty() || dictionary == itemData(currentIndex()).toString()) {
-        return;
+        return false;
     }
 
     int idx = findData(dictionary);
     if (idx == -1) {
-        qDebug() << "dictionary not found" << dictionary;
-        return;
+        qCDebug(SONNET_LOG_UI) << "dictionary not found" << dictionary;
+        return false;
     }
 
     setCurrentIndex(idx);
     d->slotDictionaryChanged(idx);
+    return true;
+}
+
+void DictionaryComboBox::setCurrentByDictionary(const QString &dictionary)
+{
+    assignByDictionnary(dictionary);
 }
 
 void DictionaryComboBox::reloadCombo()
